@@ -8,85 +8,70 @@ context("Testing GRD")
 
 
 test_that("This is the minimum specification", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD()
     head(dta)
     tail(dta)
     expect_output( str(hist(dta$DV)), "List of 6" )
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Renaming the dependant variable and setting the group size", {
-    options(superb.feedback = 'none')
-    dta <- GRD( RenameDV = "score", SubjectsPerGroup = 1000 )
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD( RenameDV = "score", SubjectsPerGroup = 200 )
     expect_output( str(hist(dta$score )), "List of 6" )
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Selecting a between-group experimental design...", {
-    options(superb.feedback = 'none')
-    expect_output( str(dta <- GRD( BSFactors = '3')), "data.frame")
-    expect_output( str( GRD( BSFactors = "3 : 2")), "data.frame")
-    expect_output( str( GRD( BSFactors = "(yes,no) : (CBT, Control, Exercice)")), "data.frame")
-    expect_output( str( GRD( BSFactors = "Stress(3)")), "data.frame")
-    expect_output( str( GRD( WSFactors = "Moment (2)")), "data.frame")
-    expect_output( str( GRD( BSFactors = "Group(3)", WSFactors = "2 : 3")), "data.frame")
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    expect_output( str(dta <- GRD( BSFactors = '3',SubjectsPerGroup = 20)), "data.frame")
+    expect_output( str( GRD( BSFactors = "3 : 2"),SubjectsPerGroup = 20), "data.frame")
+    expect_output( str( GRD( BSFactors = "(yes,no) : (CBT, Control, Exercice)"),SubjectsPerGroup = 20), "data.frame")
+    expect_output( str( GRD( BSFactors = "Stress(3)"),SubjectsPerGroup = 20), "data.frame")
+    expect_output( str( GRD( WSFactors = "Moment (2)"),SubjectsPerGroup = 20), "data.frame")
+    expect_output( str( GRD( BSFactors = "Group(3)", WSFactors = "2 : 3"),SubjectsPerGroup = 20), "data.frame")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Obtaining feedback information (not required) and a summary", {
+	old <- options() 
+	on.exit(options(old)) 
+
     # turns on all feedback information
-    options(superb.feedback = 'all')
-    expect_output( str( GRD( BSFactors = "Group(3)")), "data.frame")
+    options("superb.feedback" = 'all')
+    expect_output( str( GRD( BSFactors = "Group(3)"),SubjectsPerGroup = 20), "data.frame")
     # turns only summary information on the design (recommended)
-    options(superb.feedback = 'summary')
-    expect_output( str( GRD( BSFactors = "Group(3)")), "data.frame")
+    options("superb.feedback" = 'summary')
+    expect_output( str( GRD( BSFactors = "Group(3)"),SubjectsPerGroup = 20), "data.frame")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
-# test_that("A complete test with plots and anova", {
-    # options(superb.feedback = 'none')
-    # library(lattice)
-    # library("reshape2")
-    # library(car) #stupid package
-
-    # dta <- GRD(
-        # BSFactors = "difficulty(3) : gender (2)", 
-        # WSFactors="day(2)",
-        # SubjectsPerGroup=c(2,2,3,3,2,2)
-    # )
-      
-    # Day = factor(c("DV.1", "DV.2")) # good for anova but not for plot
-    # dta$gender = factor(dta$gender, labels=c(1,2))
-    # dta$difficulty = factor(dta$difficulty, labels=c(1,2,3))
-    # anv1 = lm(cbind(DV.1, DV.2)~difficulty*gender, data=dta)
-    # anv2 = Anova(anv1, idata=data.frame(Day), idesign=~Day, type=3)
-    # summary(anv2, multivariate=F)
-
-    # histogram(~ dta$DV.1 | difficulty, data = dta)
-    # histogram(~ dta$DV.2 | difficulty, data = dta)
-    # dta2 <- melt(dta, id.vars=c("difficulty","gender"))
-    # dta3 <- dta2[dta2$variable != "id",]
-    # dta3$gender = factor(dta3$gender, labels=c(1, 2))
-    # expect_output( str(histogram(~ value | difficulty, data = dta3)), "List of 45" )
-    # expect_output( str(histogram(~ value | difficulty + gender + variable, data = dta3)), "List of 45" )
-    #restores default information
-    # options(superb.feedback = c('design','warnings','summary'))
-# })
-
-
 test_that("Defining population characteristics (ex. 1/2)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD( 
       RenameDV = "IQ",
+	  SubjectsPerGroup = 20,
       Population=list(
         mean=100,  # will set GM to 100
         stddev=15  # will set STDDEV to 15
@@ -94,54 +79,66 @@ test_that("Defining population characteristics (ex. 1/2)", {
     )
     expect_output( str(hist(dta$IQ)), "List of 6") 
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Defining population characteristics (ex. 2/2)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
-    dta <- GRD(BSFactors="difficulty(2)", SubjectsPerGroup = 1000,
+    dta <- GRD(BSFactors="difficulty(2)", SubjectsPerGroup = 200,
       Population=list(mean=100,stddev=15)
     )
     expect_output( str(histogram(~ DV | difficulty, data = dta)), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Adding effects (ex. 1/5)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
-    dta <- GRD(BSFactors="difficulty(2)", SubjectsPerGroup = 1000,
+    dta <- GRD(BSFactors="difficulty(2)", SubjectsPerGroup = 200,
       Population=list(mean=100,stddev=15),
       Effects = list("difficulty" = extent(50) )
     )
     expect_output( str(histogram(~ DV | difficulty, data = dta)), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Adding effects (ex. 2/5)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
-    dta <- GRD(BSFactors="difficulty(5)", SubjectsPerGroup = 1000,
+    dta <- GRD(BSFactors="difficulty(5)", SubjectsPerGroup = 200,
       Population=list(mean=0,stddev=5), 
       Effects = list("difficulty" = slope(50) )
     )
     expect_output( str(histogram(~ DV | difficulty, data = dta)), "List of 45")
     expect_output( str(hist(dta$DV, breaks=seq(-150,150,by=5) )), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Adding effects (ex. 3/5)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
     dta <- GRD(BSFactors="difficulty(3):gender(2)", 
-      Population=list(mean=100,stddev=15), SubjectsPerGroup = 1000,
+      Population=list(mean=100,stddev=15), SubjectsPerGroup = 200,
       Effects = list(
         "difficulty" = extent(10),
         "gender"=slope(10),
@@ -155,16 +152,19 @@ test_that("Adding effects (ex. 3/5)", {
     )
     expect_output( str(plt), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Adding effects (ex. 4/5)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
     dta <- GRD(
       BSFactors = 'Reply(yes, no) : Therapy(CBT, Exercise, Control)',
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list(
         "Reply*Therapy"=slope(5) 
       ) 
@@ -174,16 +174,19 @@ test_that("Adding effects (ex. 4/5)", {
     )
     expect_output( str(plt), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Adding effects (ex. 5/5)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
     # The Rexpression effects are given arbitrary names 
     # instead of factors on which to operate
-    dta <- GRD(BSFactors="difficulty(5)", SubjectsPerGroup = 1000,
+    dta <- GRD(BSFactors="difficulty(5)", SubjectsPerGroup = 200,
       Population=list(mean=0,stddev=5),
       Effects = list(
         "code1" = Rexpression("if (difficulty ==1) {-50} else {0}"), 
@@ -198,27 +201,33 @@ test_that("Adding effects (ex. 5/5)", {
     # subject "id", the factor(s) values, and the DV itself
     expect_output( str(plt), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Specifying underlying distributions (ex. 1/3)", {
-    options(superb.feedback = 'none')
-    dta <- GRD(SubjectsPerGroup = 1000, 
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD(SubjectsPerGroup = 200, 
       Population=list(mean=100,stddev=15)
     )
     plt <- hist(dta$DV,breaks=seq(min(dta$DV,40)-5,max(dta$DV,160)+5,by=2.5))
     expect_output( str(plt), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Specifying underlying distributions (ex. 2/3)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
     # heterogeneous variances across groups
-    dta <- GRD(SubjectsPerGroup = 1000, 
+    dta <- GRD(SubjectsPerGroup = 200, 
       BSFactors = "Group(2)",
       Population=list(
         mean = 100, 
@@ -230,13 +239,16 @@ test_that("Specifying underlying distributions (ex. 2/3)", {
       type="density", breaks=seq(min(dta$DV)-5,max(dta$DV)+5,by=2.5) )
     expect_output( str(plt), "List of 45")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Specifying underlying distributions (ex. 3/3)", {
-    options(superb.feedback = 'none')
-    dta <- GRD(SubjectsPerGroup = 1000, 
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD(SubjectsPerGroup = 200, 
       Population=list(
         scores = "rweibull(1, shape=2, scale=40)"
       )
@@ -246,13 +258,16 @@ test_that("Specifying underlying distributions (ex. 3/3)", {
     # one by one (so that the first argument must be 1) unless rho is set
     expect_output( str(plt), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Introducing contaminants (1/2)", {
-    options(superb.feedback = 'none')
-    dta <- GRD(SubjectsPerGroup = 1000, 
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD(SubjectsPerGroup = 200, 
       Population=list(
         mean=100, stddev = 15  
       ), 
@@ -263,13 +278,16 @@ test_that("Introducing contaminants (1/2)", {
     plt <- hist(dta$DV,breaks=seq(min(dta$DV,5)-5,max(dta$DV,260)+5,by=2.5))
     expect_output( str(plt), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Introducing contaminants (2/2)", {
-    options(superb.feedback = 'none')
-    dta <- GRD(SubjectsPerGroup = 10000, 
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD(SubjectsPerGroup = 2000, 
       Population=list(
         mean=100, stddev = 15  
       ), 
@@ -280,15 +298,18 @@ test_that("Introducing contaminants (2/2)", {
     plt <- hist(dta$DV,breaks=seq(min(dta$DV,5)-5,max(dta$DV,260)+5,by=2.5))
     expect_output( str(plt), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("Generating multivariate normal data (1/2)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(lattice)
     dta <- GRD( BSFactors="grp(2)",WSFactors = "Moment (2)", 
-       SubjectsPerGroup = 1000,
+       SubjectsPerGroup = 200,
        Population=list(mean=0,stddev=20,rho=-0.85), 
        Contaminant=list(mean=100,stddev=4,rho=-0.99,proportion=0.25)
     )
@@ -299,14 +320,17 @@ test_that("Generating multivariate normal data (1/2)", {
     expect_output( str(plt1), "List of 45")
     expect_output( str(plt2), "NULL")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })     
 
 
 test_that("Generating multivariate normal data (2/2)", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD( BSFactors="grp(2)",WSFactors = "Moment (2)", 
-       SubjectsPerGroup = 1000,
+       SubjectsPerGroup = 200,
        Effects = list("grp" = slope(100) ),
        Population=list(mean=0,stddev=20,rho=-0.85), 
        Contaminant=list(mean=100,stddev=4,rho=-0.99,proportion=0.25)
@@ -318,7 +342,7 @@ test_that("Generating multivariate normal data (2/2)", {
 
     # restores parameters
     par(oldpar)
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
@@ -330,17 +354,23 @@ test_that("Generating multivariate normal data (2/2)", {
 
 
 test_that("page 4", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD()
     expect_output( str(dta), "data.frame")
     expect_equal( dim(dta), c(100,2))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 5", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD()
     top <- head(dta,2)
     bot <- tail (dta,2)
@@ -350,22 +380,28 @@ test_that("page 5", {
     expect_output( str(bot), "data.frame")
     expect_output( str(plt), "List of 6")
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 6", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD( RenameDV = "score")
     expect_output( str(dta), "data.frame")
     expect_equal( dim(dta), c(100,2))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 7", { 
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta1 <- GRD( BSFactors = "3")
     head(dta1,2)
     dta2 <- GRD( BSFactors = "2 : 3")
@@ -374,12 +410,15 @@ test_that("page 7", {
     expect_equal( dim(dta2), c(600,4))
     expect_equal( dim(dta3), c(600,4))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 8", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD( BSFactors = "Surgery(2) : Therapy(3)")
     expect_equal( dim(dta), c(600,4))
     dta <- GRD( BSFactors = "Surgery(yes,no) : Therapy(CBT, Control, Exercice)")
@@ -392,28 +431,34 @@ test_that("page 8", {
     head(dta, 2)
     expect_equal( dim(dta), c(100,4))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 9", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       BSFactors = "Surgery(yes,no) : Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(Low,Medium,High)"  
     )
     expect_equal( dim(dta), c(600,6))
-    dta <- GRD( SubjectsPerGroup = 1000 )
-    expect_equal( dim(dta), c(1000,2))
+    dta <- GRD( SubjectsPerGroup = 200 )
+    expect_equal( dim(dta), c(200,2))
     dta <- GRD( BSFactors = "3", SubjectsPerGroup = c(20,25,50) )
     expect_equal( dim(dta), c(95,3))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 10", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       RenameDV = "IQ", 
       Population = list(mean = 100, stddev = 15)
@@ -426,12 +471,15 @@ test_that("page 10", {
     )
     expect_equal( dim(dta), c(200,3))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 11", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       BSFactors = "Group(2)",
       Population = list(scores = "Group")
@@ -457,13 +505,16 @@ test_that("page 11", {
     tt <- levene.test(dta$DV, dta$Group, location="mean")
     expect_output( str(tt), "List of 5" )
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 12", {
-    options(superb.feedback = 'none')
-    dta <- GRD( SubjectsPerGroup = 5000,
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
+    dta <- GRD( SubjectsPerGroup = 500,
       RenameDV = "RT", 
       Population = list(
         scores = "rweibull(1, shape=2, scale=40)+250"
@@ -472,16 +523,19 @@ test_that("page 12", {
     plt <- hist(dta$RT, breaks = seq(250, 425, by = 5) ) 
     expect_output( str(plt), "List of 6" )
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 14", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list("Therapy" = slope(2) )
     )
     library(lattice)
@@ -492,7 +546,7 @@ test_that("page 14", {
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list("Contrast" = extent(4) )
     )
     library(lsr)
@@ -503,26 +557,29 @@ test_that("page 14", {
     )
     expect_output( str(plt), "List of 45" )
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 15", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list("Therapy" = custom(0,0,2) )
     )
-    expect_equal( dim(dta), c(3000,5))
+    expect_equal( dim(dta), c(600,5))
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list("Therapy*Contrast" = slope(10) )
     )
-    expect_equal( dim(dta), c(3000,5))
+    expect_equal( dim(dta), c(600,5))
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
@@ -534,12 +591,15 @@ test_that("page 15", {
     )
     expect_equal( dim(dta), c(30,5))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("# page 16", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       BSFactors = "Therapy(CBT, Control, Exercice)",
       WSFactors = "Contrast(3)",
@@ -566,69 +626,78 @@ test_that("# page 16", {
 
     dta <- GRD(
       WSFactors = "Difficulty(2)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population = list(Mean = 0, stddev = 20, rho = 0.5)
     )
-    expect_equal( dim(dta), c(1000,3))
+    expect_equal( dim(dta), c(200,3))
     plot(dta$DV.1, dta$DV.2)
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 17", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
       WSFactors = "Difficulty(2)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population = list(Mean = c(10,2), stddev = c(1,0.2), rho = -0.85)
     )
     plot(dta$DV.1, dta$DV.2)
-    expect_equal( dim(dta), c(1000,3))
+    expect_equal( dim(dta), c(200,3))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 18", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     library(fMultivar)
     # the parameters of the rmsn distribution are
     # xi, omega, alpha
     dta <- GRD(
       WSFactors = "Difficulty(2)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population = list(rho = 99,
         scores = 'sn::rmsn(1, c(0,0), as.array(cbind(c(1,0.5),c(0.5,1))), c(2,-6))'
       )
     )
     plot(dta$DV.1, dta$DV.2)
-    expect_equal( dim(dta), c(1000,3))
+    expect_equal( dim(dta), c(200,3))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 19", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
-      SubjectsPerGroup = 5000,
+      SubjectsPerGroup = 500,
       Population = list(mean = 100, stddev = 15 ),
       Contaminant = list(mean = 200, stddev = 15, proportion = 0.1) 
     )
     hist(dta$DV, breaks = seq(min(dta$DV,5)-5,max(dta$DV,260)+5,by=2.5))
-    expect_equal( dim(dta), c(5000,2))
+    expect_equal( dim(dta), c(500,2))
 
     dta <- GRD(
-      SubjectsPerGroup = 5000,
+      SubjectsPerGroup = 500,
       Population = list(mean = 100, stddev = 15 ),
       Contaminant = list(scores = 'rweibull(1,shape=1.5,scale=30)+1.5*GM', proportion = 0.1) 
     )
     hist(dta$DV, breaks = seq(min(dta$DV)-5,max(dta$DV)+5,by=2.5))
-    expect_equal( dim(dta), c(5000,2))
+    expect_equal( dim(dta), c(500,2))
 
     dta <- GRD( BSFactors="grp(2)",WSFactors="M(2)",
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Effects = list("grp"=slope(100)),
       Population = list(mean = 0, stddev = 15, rho=-0.85 ),
       Contaminant = list(mean =100, stddev = 4, rho = -0.99, proportion = 0.1) 
@@ -638,24 +707,27 @@ test_that("page 19", {
       ylim = c(-150,150), xlim = c(-150,150))
     plot(dta[dta$grp ==2,]$DV.1,dta[dta$grp==2,]$DV.2,
       ylim = c(-150,150), xlim = c(-150,150))
-    expect_equal( dim(dta), c(2000,4))
+    expect_equal( dim(dta), c(400,4))
 
     # restores parameters
     par(oldpar)
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("page 20", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     dta <- GRD(
-      SubjectsPerGroup = 5000,
+      SubjectsPerGroup = 500,
       Population = list(mean = 100, stddev = 15 ),
       Contaminant = list(scores = 'NA', proportion = 0.1) 
     )
-    expect_equal( dim(dta), c(5000,2))
+    expect_equal( dim(dta), c(500,2))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
@@ -668,10 +740,13 @@ test_that("page 20", {
 
 
 test_that("figure 1", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     oldpar <- par(mfrow=c(1,3))
     # panel 1: unaffected (p. 4)
-    dta <- GRD( SubjectsPerGroup = 1000 )
+    dta <- GRD( SubjectsPerGroup = 200 )
     hist(dta$DV )
     # panel 2: IQ example (p. 10)
     dta <- GRD( 
@@ -680,23 +755,26 @@ test_that("figure 1", {
     )
     hist(dta$IQ)
     # panel 3: weibull (p. 12)
-    dta <- GRD(SubjectsPerGroup = 5000, 
+    dta <- GRD(SubjectsPerGroup = 500, 
       RenameDV = "RT",
       Population=list(
         scores = "rweibull(1, shape=2, scale=40)+250"
       )
     )
     hist(dta$RT,breaks=seq(min(dta$DV,245)-5,max(dta$DV,410)+5,by=5))
-    expect_equal( dim(dta), c(5000,2))
+    expect_equal( dim(dta), c(500,2))
 
     # restores parameters
     par(oldpar)
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("figure 2:", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     # panel 1: a slope of 2 on Therapy (p. 14)
     dta <- GRD(
       BSFactors = 'Surgery(yes, no) : Therapy(CBT, Control, Exercise)',
@@ -734,24 +812,27 @@ test_that("figure 2:", {
     print(p3, position=c(0.25, 0.00, 0.75, 0.50))
     expect_equal( dim(dta), c(600,6))
     # restores default information
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("figure 3:", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     oldpar <- par(mfrow=c(1,3))
     # panel 1: multivariate normal
     dta <- GRD( 
       WSFactors = 'Difficulty(1,2)',
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population=list(mean=0,stddev=20,rho=0.5)
     )
     plot(dta$DV.1, dta$DV.2)
     # panel 2: multivariate normal
     dta <- GRD( 
       WSFactors = 'Difficulty(1,2)',
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population=list(mean=c(10,2),stddev=c(1,0.2),rho=-0.85)
     )
     plot(dta$DV.1, dta$DV.2)
@@ -762,29 +843,32 @@ test_that("figure 3:", {
 
     dta <- GRD( 
       WSFactors = 'Difficulty(1, 2)',
-      SubjectsPerGroup = 1000,
+      SubjectsPerGroup = 200,
       Population=list(rho=99,scores="sn::rmsn(1, c(0,0), as.array(cbind(c(1,0.5),c(0.5,1))), c(2,-6) )")
     )
     plot(dta$DV.1, dta$DV.2)
-    expect_equal( dim(dta), c(1000,3))
+    expect_equal( dim(dta), c(200,3))
 
     # restores parameters
     par(oldpar)
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
 test_that("figure 4:", {
-    options(superb.feedback = 'none')
+	old <- options() 
+	on.exit(options(old)) 
+    options("superb.feedback" = 'none')
+
     oldpar <- par(mfrow=c(1,4))
     # panel 1
-    dta <- GRD(SubjectsPerGroup = 5000, 
+    dta <- GRD(SubjectsPerGroup = 500, 
       Population=list( mean=100, stddev = 15 ), 
       Contaminant=list( mean=200, stddev = 15, proportion = 0.10 )
     )
     hist(dta$DV,breaks=seq(min(dta$DV,5)-5,max(dta$DV,260)+5,by=2.5))
     #panel 2
-    dta <- GRD(SubjectsPerGroup = 10000, 
+    dta <- GRD(SubjectsPerGroup = 1000, 
       Population=list( mean=100, stddev = 15 ), 
       Contaminant=list(
         scores="rweibull(1,shape=1.5, scale=30)+2*GM", proportion = 0.10
@@ -793,7 +877,7 @@ test_that("figure 4:", {
     hist(dta$DV,breaks=seq(min(dta$DV,5)-5,max(dta$DV,360)+5,by=2.5))
     # panel 3
     dta <- GRD( BSFactors="grp(2)",WSFactors = "Moment (2)", 
-       SubjectsPerGroup = 1000,
+       SubjectsPerGroup = 200,
        Effects = list("grp" = slope(100) ),
        Population=list(mean=0,stddev=20,rho=-0.85), 
        Contaminant=list(mean=100,stddev=4,rho=-0.99,proportion=0.2),
@@ -801,11 +885,11 @@ test_that("figure 4:", {
     plot(dta[dta$grp == 1,]$DV.1,dta[dta$grp==1,]$DV.2, ylim=c(-150,150), xlim=c(-150,150))
     plot(dta[dta$grp == 2,]$DV.1,dta[dta$grp==2,]$DV.2, ylim=c(-150,150), xlim=c(-150,150)) 
     #done
-    expect_equal( dim(dta), c(2000,4))
+    expect_equal( dim(dta), c(400,4))
 
     # restores parameters
     par(oldpar)
-    options(superb.feedback = c('design','warnings','summary'))
+    options("superb.feedback" = c('design','warnings','summary'))
 })
 
 
